@@ -10,7 +10,7 @@ use Error::Pure qw(err);
 use PYX::Parser;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -310,12 +310,13 @@ L<PYX::Parser>.
 
 =head1 SEE ALSO
 
-L<PYX>,
-L<PYX::GraphViz>,
-L<PYX::Hist>,
-L<PYX::Parser>,
-L<PYX::Utils>,
-L<Task::PYX>.
+=over
+
+=item L<Task::PYX>
+
+Install the PYX modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -334,6 +335,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
